# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class HclAppScanOnCloudUrl(str, enum.Enum):
    CLOUD_APPSCAN_COM = "https://cloud.appscan.com"
    EU_CLOUD_APPSCAN_COM = "https://eu.cloud.appscan.com"

    def visit(
        self, cloud_appscan_com: typing.Callable[[], T_Result], eu_cloud_appscan_com: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is HclAppScanOnCloudUrl.CLOUD_APPSCAN_COM:
            return cloud_appscan_com()
        if self is HclAppScanOnCloudUrl.EU_CLOUD_APPSCAN_COM:
            return eu_cloud_appscan_com()
