# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppSecApplicationUidType(str, enum.Enum):
    PROVIDER_RELEASE = "provider_release"
    PROVIDER_APPLICATION = "provider_application"

    def visit(
        self, provider_release: typing.Callable[[], T_Result], provider_application: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is AppSecApplicationUidType.PROVIDER_RELEASE:
            return provider_release()
        if self is AppSecApplicationUidType.PROVIDER_APPLICATION:
            return provider_application()
