# This file was auto-generated by Fern from our API Definition.

from .....v_1_5_0.resources.applicationsecurityposturefinding.resources.classes.types.application_security_posture_finding import (
    ApplicationSecurityPostureFinding as resources_ocsf_resources_v_1_5_0_resources_applicationsecurityposturefinding_resources_classes_types_application_security_posture_finding_ApplicationSecurityPostureFinding,
)

ApplicationSecurityPostureFinding = resources_ocsf_resources_v_1_5_0_resources_applicationsecurityposturefinding_resources_classes_types_application_security_posture_finding_ApplicationSecurityPostureFinding
